# Roadmap for pyPicoSDK
## WIP
- 6000 (A) API Signal Generator
- Documentation
    - Complete docStrings for pypicoSDK
        - Adding constants docstrings
    - Extend ref introduction
- Upload & test pypi (pip)
    - `setup.py` created, needs refining
    - Current in [test pypi](https://test.pypi.org/project/pypicosdk/)

## To-Do
- 6000 (A) streaming support
- Add `run_simple_block_capture()` for 5000 (A)
- Add support for 3000 (A) drivers
- Test & add support for macOS & linux
